export PLATFORM_TARGET
#export VERBOSE_SCRIPTS="1" // Generate verbose build for all project modules

###########################################################################################
# Environment Configuration for the platform
###########################################################################################
export LC_ALL=en_US

export PRODUCTION_FLAG="YES"
export RELEASE_VERSION="YES"

export BASE_DIR=${PWD}
export SDK=${BASE_DIR}/sdk
export COMMON=${SDK}/common

export PATH:=${PATH}:${COMMON}/bin
export CMAKE_EXEC=${COMMON}/cmake

export AR=${CROSS_COMPILE}-ar
export AS=${CROSS_COMPILE}-as
export LD=${CROSS_COMPILE}-ld
export NM=${CROSS_COMPILE}-nm
export CC=${CROSS_COMPILE}-gcc
export CPP=${CROSS_COMPILE}-cpp
export GCC=${CROSS_COMPILE}-gcc
export CXX=${CROSS_COMPILE}-g++
export OBJCOPY=${CROSS_COMPILE}-objcopy
export RANLIB=${CROSS_COMPILE}-ranlib

export cc=${CC}
export cpp=${CPP}
export cxx=${CXX}
export as=${AS}
export ar=${AR}
export ld=${LD}
export ranlib=${RANLIB}

export EXTERNALSROOT=${BASE_DIR}/externals
export SDKROOT=${BASE_DIR}/sdk
export CONFIGSROOT=${BASE_DIR}/configs
export DEPLOY_DIR=${BASE_DIR}/deploy
export BUILD_DIR=${BASE_DIR}/build

## Revision variable to be used by any product component
export PROJECT_REVISION="100"
export REVISION_SDK="100"


export TQTVD_BUILD_ASTRONAV=SHARED

###########################################################################################
## Platform attributes
export MAX_MEM_GM_VID=25165824
export MAX_MEM_GM_SYS=0

###########################################################################################
## Build flags

ifeq ($(findstring debug, $(MAKECMDGOALS)), debug)
	COREFLAGS=-O0 -ggdb -fno-omit-frame-pointer -rdynamic \
	-funwind-tables # Required to obtain stack traces on some platforms
	export STRIP=null.sh
else
	COREFLAGS=-O2 -march=armv7-a -mtune=cortex-a9 -mfloat-abi=softfp -mfpu=neon-vfpv4 -DNDEBUG
	
	ifeq ($(findstring nostrip, $(MAKECMDGOALS)), nostrip)
		COREFLAGS += -fno-omit-frame-pointer -rdynamic \
	-funwind-tables # Required to obtain stack traces on some platforms
		export STRIP=null.sh
	else
		COREFLAGS += -fomit-frame-pointer
		export STRIP=${CROSS_COMPILE}-strip
	endif
endif

COREFLAGS += -DMODEL=FF # to be defined

BASEFLAGS=-fPIC -Wall -Wno-undef -Wno-cast-qual -Wno-comment -Wno-write-strings -Wno-parentheses -Wreturn-type \
-Wunused-value -Wunused-variable -Wpointer-arith -Wno-unused-function -Wno-unused-but-set-variable -Wno-deprecated-declarations \
-fno-strict-aliasing -fsigned-char -fno-aggressive-loop-optimizations -fno-builtin -ffunction-sections \
-fdata-sections -fno-short-enums \
-DLINUX_THREADS=8000 -DNPTL=8001 -D_LINUX_ -D__ARM__ -D__arm__ -D_REENTRANT \
-DOPENSSL_NO_DGRAM -DNO_SYSLOG -DNO_SYS_UN_H \
-D_GNU_SOURCE -D__ARM_EABI__ -DFAR=

BASEFLAGS += -I${ZLIB_CFLAGS} -I${XML2_CFLAGS}


CFLAGS=${COREFLAGS} ${BASEFLAGS} -Wstrict-prototypes
CFLAGS_DBG=${COREFLAGS_DBG} ${BASEFLAGS} -Wstrict-prototypes

CXXFLAGS=${COREFLAGS} ${BASEFLAGS}
CXXFLAGS_DBG=${COREFLAGS_DBG} ${BASEFLAGS}

LDFLAGS = -lpthread -L${ZLIB_LDFLAGS} -lz

export CFLAGS CFLAGS_DBG CXXFLAGS CXXFLAGS_DBG LDFLAGS
